Index: /trunk/geant4/visualization/OpenGL/include/G4OpenGLImmediateQt.hh
===================================================================
--- /trunk/geant4/visualization/OpenGL/include/G4OpenGLImmediateQt.hh	(revision 532)
+++ /trunk/geant4/visualization/OpenGL/include/G4OpenGLImmediateQt.hh	(revision 533)
@@ -25,20 +25,20 @@
 //
 //
-// $Id: G4OpenGLImmediateWin32.hh,v 1.7 2006/06/29 21:17:44 gunter Exp $
+// $Id: G4OpenGLImmediateQt.hh,v 1.7 2007/06/25 21:17:44 $
 // GEANT4 tag $Name: geant4-08-01-patch-01 $
 //
 // 
-// OpenGLImmediateWin32 graphics system factory.
+// OpenGLImmediateQt graphics system factory.
 
-#if defined (G4VIS_BUILD_OPENGLWIN32_DRIVER) || defined (G4VIS_USE_OPENGLWIN32)
+#if defined (G4VIS_BUILD_OPENGLQT_DRIVER) || defined (G4VIS_USE_OPENGLQT)
 
-#ifndef G4OPENGLIMMEDIATEWIN32_HH
-#define G4OPENGLIMMEDIATEWIN32_HH
+#ifndef G4OPENGLIMMEDIATEQT_HH
+#define G4OPENGLIMMEDIATEQT_HH
 
 #include "G4VGraphicsSystem.hh"
 
-class G4OpenGLImmediateWin32: public G4VGraphicsSystem {
+class G4OpenGLImmediateQt: public G4VGraphicsSystem {
 public:
-  G4OpenGLImmediateWin32 ();
+  G4OpenGLImmediateQt ();
   G4VSceneHandler* CreateSceneHandler (const G4String& name = "");
   G4VViewer*  CreateViewer  (G4VSceneHandler&, const G4String& name = "");
Index: /trunk/geant4/visualization/OpenGL/include/G4OpenGLStoredQt.hh
===================================================================
--- /trunk/geant4/visualization/OpenGL/include/G4OpenGLStoredQt.hh	(revision 532)
+++ /trunk/geant4/visualization/OpenGL/include/G4OpenGLStoredQt.hh	(revision 533)
@@ -25,20 +25,20 @@
 //
 //
-// $Id: G4OpenGLStoredWin32.hh,v 1.7 2006/06/29 21:18:04 gunter Exp $
+// $Id: G4OpenGLStoredQt.hh,v 1.7 2007/06/25 21:18:04 $
 // GEANT4 tag $Name: geant4-08-01-patch-01 $
 //
 // 
-// OpenGLStoredWin32 graphics system factory.
+// OpenGLStoredQt graphics system factory.
 
-#if defined (G4VIS_BUILD_OPENGLWIN32_DRIVER) || defined (G4VIS_USE_OPENGLWIN32)
+#if defined (G4VIS_BUILD_OPENGLQT_DRIVER) || defined (G4VIS_USE_OPENGLQT)
 
-#ifndef G4OPENGLSTOREDWIN32_HH
-#define G4OPENGLSTOREDWIN32_HH
+#ifndef G4OPENGLSTOREDQT_HH
+#define G4OPENGLSTOREDQT_HH
 
 #include "G4VGraphicsSystem.hh"
 
-class G4OpenGLStoredWin32: public G4VGraphicsSystem {
+class G4OpenGLStoredQt: public G4VGraphicsSystem {
 public:
-  G4OpenGLStoredWin32 ();
+  G4OpenGLStoredQt ();
   G4VSceneHandler* CreateSceneHandler (const G4String& name = "");
   G4VViewer*  CreateViewer  (G4VSceneHandler&, const G4String& name = "");
Index: /trunk/geant4/visualization/management/include/G4VisExecutive.icc
===================================================================
--- /trunk/geant4/visualization/management/include/G4VisExecutive.icc	(revision 532)
+++ /trunk/geant4/visualization/management/include/G4VisExecutive.icc	(revision 533)
@@ -71,6 +71,6 @@
 
 #ifdef G4VIS_USE_OPENGLQT
-#include "G4OpenGLQt.hh"
-#include "G4OpenGLQt.hh"
+#include "G4OpenGLImmediateQt.hh"
+#include "G4OpenGLStoredQt.hh"
 #endif
 

Index: /trunk/geant4/visualization/OpenGL/include/G4OpenGLImmediateQtViewer.hh
===================================================================
--- /trunk/geant4/visualization/OpenGL/include/G4OpenGLImmediateQtViewer.hh	(revision 532)
+++ /trunk/geant4/visualization/OpenGL/include/G4OpenGLImmediateQtViewer.hh	(revision 533)
@@ -25,19 +25,19 @@
 //
 //
-// $Id: G4OpenGLImmediateWin32Viewer.hh,v 1.9 2006/06/29 21:17:46 gunter Exp $
+// $Id: G4OpenGLImmediateQtViewer.hh,v 1.9 2007/06/25 21:17:46 $
 // GEANT4 tag $Name: geant4-08-01-patch-01 $
 //
 // 
 // Class G4OpenGLImmediateWin32Viewer : a class derived from
 //   G4OpenGLWin32Viewer and G4OpenGLImmediateViewer.
 
-#ifdef G4VIS_BUILD_OPENGLWIN32_DRIVER
+#ifdef G4VIS_BUILD_OPENGLQT_DRIVER
 
-#ifndef G4OpenGLIMMEDIATEWIN32VIEWER_HH
-#define G4OpenGLIMMEDIATEWIN32VIEWER_HH
+#ifndef G4OpenGLIMMEDIATEQTVIEWER_HH
+#define G4OpenGLIMMEDIATEQTVIEWER_HH
 
 #include "G4VViewer.hh"
 #include "G4OpenGLImmediateViewer.hh"
-#include "G4OpenGLWin32Viewer.hh"
+#include "G4OpenGLQtViewer.hh"
 
 #include "globals.hh"
@@ -45,9 +45,9 @@
 class G4OpenGLImmediateSceneHandler;
 
-class G4OpenGLImmediateWin32Viewer:
-public G4OpenGLWin32Viewer, public G4OpenGLImmediateViewer{
+class G4OpenGLImmediateQtViewer:
+public G4OpenGLQtViewer, public G4OpenGLImmediateViewer{
   
 public:
-  G4OpenGLImmediateWin32Viewer (G4OpenGLImmediateSceneHandler& scene,
+  G4OpenGLImmediateQtViewer (G4OpenGLImmediateSceneHandler& scene,
 				const G4String& name = "");
   void Initialise ();
@@ -25,19 +25,19 @@
 //
 // 
-// Class G4OpenGLImmediateWin32Viewer : a class derived from
-//   G4OpenGLWin32Viewer and G4OpenGLImmediateViewer.
+// Class G4OpenGLImmediateQtViewer : a class derived from
+//   G4OpenGLQtViewer and G4OpenGLImmediateViewer.
 
Index: /trunk/geant4/visualization/OpenGL/include/G4OpenGLStoredQtViewer.hh
===================================================================
--- /trunk/geant4/visualization/OpenGL/include/G4OpenGLStoredQtViewer.hh	(revision 532)
+++ /trunk/geant4/visualization/OpenGL/include/G4OpenGLStoredQtViewer.hh	(revision 533)
@@ -25,27 +25,27 @@
 //
 //
-// $Id: G4OpenGLStoredWin32Viewer.hh,v 1.7 2006/06/29 21:18:06 gunter Exp $
+// $Id: G4OpenGLStoredQtViewer.hh,v 1.7 2007/06/25 21:18:06 $
 // GEANT4 tag $Name: geant4-08-01-patch-01 $
 //
 // 
 // Class G4OpenGLStoredWin32Viewer : a class derived from
 //   G4OpenGLWin32Viewer and G4OpenGLStoredViewer.
 
-#ifdef G4VIS_BUILD_OPENGLWIN32_DRIVER
+#ifdef G4VIS_BUILD_OPENGLQT_DRIVER
 
-#ifndef G4OPENGLSTOREDWIN32VIEWER_HH
-#define G4OPENGLSTOREDWIN32VIEWER_HH
+#ifndef G4OPENGLSTOREDQTVIEWER_HH
+#define G4OPENGLSTOREDQTVIEWER_HH
 
 #include "G4VViewer.hh"
 #include "G4OpenGLStoredViewer.hh"
-#include "G4OpenGLWin32Viewer.hh"
+#include "G4OpenGLQtViewer.hh"
 
 class G4OpenGLStoredSceneHandler;
 
-class G4OpenGLStoredWin32Viewer:
-public G4OpenGLWin32Viewer, public G4OpenGLStoredViewer{
+class G4OpenGLStoredQtViewer:
+public G4OpenGLQtViewer, public G4OpenGLStoredViewer{
   
 public:
-  G4OpenGLStoredWin32Viewer (G4OpenGLStoredSceneHandler& scene,
+  G4OpenGLStoredQtViewer (G4OpenGLStoredSceneHandler& scene,
 			     const G4String& name = "");
   void Initialise ();
@@ -25,27 +25,27 @@
 //
 // 
-// Class G4OpenGLStoredWin32Viewer : a class derived from
-//   G4OpenGLWin32Viewer and G4OpenGLStoredViewer.
+// Class G4OpenGLStoredQtViewer : a class derived from
+//   G4OpenGLQtViewer and G4OpenGLStoredViewer.
 
Index: /trunk/geant4/visualization/OpenGL/src/G4OpenGLImmediateQt.cc
===================================================================
--- /trunk/geant4/visualization/OpenGL/src/G4OpenGLImmediateQt.cc	(revision 532)
+++ /trunk/geant4/visualization/OpenGL/src/G4OpenGLImmediateQt.cc	(revision 533)
@@ -25,11 +25,11 @@
 //
 //
-// $Id: G4OpenGLImmediateWin32.cc,v 1.11 2006/08/14 12:07:19 allison Exp $
+// $Id: G4OpenGLImmediateQt.cc,v 1.11 2007/06/24 12:07:19 $
 // GEANT4 tag $Name: geant4-08-02-patch-01 $
 //
 // 
 // OpenGLImmediateWin32 graphics system factory.
 
-#ifdef G4VIS_BUILD_OPENGLWIN32_DRIVER
+#ifdef G4VIS_BUILD_OPENGLQT_DRIVER
 
 #include "G4VisFeaturesOfOpenGL.hh"
@@ -37,12 +37,12 @@
 #include "G4OpenGLSceneHandler.hh"
 #include "G4OpenGLViewer.hh"
-#include "G4OpenGLImmediateWin32.hh"
-#include "G4OpenGLImmediateWin32Viewer.hh"
+#include "G4OpenGLImmediateQt.hh"
+#include "G4OpenGLImmediateQtViewer.hh"
 #include "G4OpenGLViewerMessenger.hh"
 
-G4OpenGLImmediateWin32::G4OpenGLImmediateWin32 ():
-  G4VGraphicsSystem ("OpenGLImmediateWin32",
-		     "OGLIWin32",
-		     G4VisFeaturesOfOpenGLIWin32 (),
+G4OpenGLImmediateQt::G4OpenGLImmediateQt ():
+  G4VGraphicsSystem ("OpenGLImmediateQt",
+		     "OGLIQt",
+		     G4VisFeaturesOfOpenGLIQt (),
 		     G4VGraphicsSystem::threeD)
 {
@@ -50,5 +50,5 @@
 }
 
-G4VSceneHandler* G4OpenGLImmediateWin32::CreateSceneHandler
+G4VSceneHandler* G4OpenGLImmediateQt::CreateSceneHandler
 (const G4String& name) {
   G4VSceneHandler* pScene = new G4OpenGLImmediateSceneHandler (*this, name);
@@ -56,13 +56,13 @@
 }
 
-G4VViewer* G4OpenGLImmediateWin32::CreateViewer
+G4VViewer* G4OpenGLImmediateQt::CreateViewer
 (G4VSceneHandler& scene, const G4String& name) {
   G4VViewer* pView =
-    new G4OpenGLImmediateWin32Viewer
+    new G4OpenGLImmediateQtViewer
     ((G4OpenGLImmediateSceneHandler&) scene, name);
   if (pView) {
     if (pView -> GetViewId () < 0) {
-      G4cerr << "G4OpenGLImmediateWin32::CreateViewer: error flagged by negative"
-	" view id in G4OpenGLImmediateWin32Viewer creation."
+      G4cerr << "G4OpenGLImmediateQt::CreateViewer: error flagged by negative"
+	" view id in G4OpenGLImmediateQtViewer creation."
 	"\n Destroying view and returning null pointer."
 	   << G4endl;
@@ -72,6 +72,6 @@
   }
   else {
-    G4cerr << "G4OpenGLImmediateWin32::CreateViewer: null pointer on"
-      " new G4OpenGLImmediateWin32Viewer." << G4endl;
+    G4cerr << "G4OpenGLImmediateQt::CreateViewer: null pointer on"
+      " new G4OpenGLImmediateQtViewer." << G4endl;
   }
   return pView;
@@ -25,11 +25,11 @@
 //
 // 
-// OpenGLImmediateWin32 graphics system factory.
+// OpenGLImmediateQt graphics system factory.
 
Index: /trunk/geant4/visualization/OpenGL/src/G4OpenGLImmediateQtViewer.cc
===================================================================
--- /trunk/geant4/visualization/OpenGL/src/G4OpenGLImmediateQtViewer.cc	(revision 532)
+++ /trunk/geant4/visualization/OpenGL/src/G4OpenGLImmediateQtViewer.cc	(revision 533)
@@ -25,22 +25,22 @@
 //
 //
-// $Id: G4OpenGLImmediateWin32Viewer.cc,v 1.16 2006/07/03 16:38:13 allison Exp $
+// $Id: G4OpenGLImmediateQtViewer.cc,v 1.16 2007/06/25 16:38:13 $
 // GEANT4 tag $Name: geant4-08-02-patch-01 $
 //
 // 
 // Class G4OpenGLImmediateWin32Viewer : a class derived from G4OpenGLWin32Viewer and
 //                                G4OpenGLImmediateViewer.
 
-#ifdef G4VIS_BUILD_OPENGLWIN32_DRIVER
+#ifdef G4VIS_BUILD_OPENGLQT_DRIVER
 
-#include "G4OpenGLImmediateWin32Viewer.hh"
+#include "G4OpenGLImmediateQtViewer.hh"
 
 #include "G4ios.hh"
 
-G4OpenGLImmediateWin32Viewer::G4OpenGLImmediateWin32Viewer
+G4OpenGLImmediateQtViewer::G4OpenGLImmediateQtViewer
 (G4OpenGLImmediateSceneHandler& sceneHandler,
  const G4String&  name):
 G4OpenGLViewer (sceneHandler),
-G4OpenGLWin32Viewer (sceneHandler),
+G4OpenGLQtViewer (sceneHandler),
 G4OpenGLImmediateViewer (sceneHandler),
 G4VViewer (sceneHandler, sceneHandler.IncrementViewCount (), name) {
@@ -49,9 +49,9 @@
 }
 
-void G4OpenGLImmediateWin32Viewer::Initialise () {
+void G4OpenGLImmediateQtViewer::Initialise () {
 
 // ensure a suitable window was found
 
-  CreateGLWin32Context ();
+  CreateGLQtContext ();
   CreateMainWindow ();
   CreateFontLists ();
@@ -69,5 +69,5 @@
 }
 
-void G4OpenGLImmediateWin32Viewer::DrawView () {
+void G4OpenGLImmediateQtViewer::DrawView () {
 
   // If a double buffer context has been forced upon us, ignore the
@@ -78,5 +78,5 @@
 
   //Make sure current viewer is attached and clean...
-  //Win32 version needed
+  //Qt version needed
   //glXMakeCurrent (dpy, win, cx);
   glViewport (0, 0, WinSize_x, WinSize_y);
@@ -101,5 +101,5 @@
 
 //////////////////////////////////////////////////////////////////////////////
-void G4OpenGLImmediateWin32Viewer::FinishView (
+void G4OpenGLImmediateQtViewer::FinishView (
 ) 
 //////////////////////////////////////////////////////////////////////////////
@@ -25,22 +25,22 @@
 //
 // 
-// Class G4OpenGLImmediateWin32Viewer : a class derived from G4OpenGLWin32Viewer and
+// Class G4OpenGLImmediateQtViewer : a class derived from G4OpenGLQtViewer and
 //                                G4OpenGLImmediateViewer.
 
Index: /trunk/geant4/visualization/OpenGL/src/G4OpenGLStoredQt.cc
===================================================================
--- /trunk/geant4/visualization/OpenGL/src/G4OpenGLStoredQt.cc	(revision 532)
+++ /trunk/geant4/visualization/OpenGL/src/G4OpenGLStoredQt.cc	(revision 533)
@@ -25,12 +25,12 @@
 //
 //
-// $Id: G4OpenGLStoredWin32.cc,v 1.14 2006/08/14 12:07:19 allison Exp $
+// $Id: G4OpenGLStoredQt.cc,v 1.14 2007/06/25 12:07:19 $
 // GEANT4 tag $Name: geant4-08-02-patch-01 $
 //
 // 
 // OpenGLStoredWin32 graphics system factory.
 
 
-#ifdef G4VIS_BUILD_OPENGLWIN32_DRIVER
+#ifdef G4VIS_BUILD_OPENGLQT_DRIVER
 
 #include "G4VisFeaturesOfOpenGL.hh"
@@ -38,12 +38,12 @@
 #include "G4OpenGLSceneHandler.hh"
 #include "G4OpenGLViewer.hh"
-#include "G4OpenGLStoredWin32.hh"
-#include "G4OpenGLStoredWin32Viewer.hh"
+#include "G4OpenGLStoredQt.hh"
+#include "G4OpenGLStoredQtViewer.hh"
 #include "G4OpenGLViewerMessenger.hh"
 
-G4OpenGLStoredWin32::G4OpenGLStoredWin32 ():
-  G4VGraphicsSystem ("OpenGLStoredWin32",
-		     "OGLSWin32",
-		     G4VisFeaturesOfOpenGLSWin32 (),
+G4OpenGLStoredQt::G4OpenGLStoredQt ():
+  G4VGraphicsSystem ("OpenGLStoredQt",
+		     "OGLSQt",
+		     G4VisFeaturesOfOpenGLSQt (),
 		     G4VGraphicsSystem::threeD)
 {
@@ -51,5 +51,5 @@
 }
 
-G4VSceneHandler* G4OpenGLStoredWin32::CreateSceneHandler
+G4VSceneHandler* G4OpenGLStoredQt::CreateSceneHandler
 (const G4String& name) {
   G4VSceneHandler* pScene = new G4OpenGLStoredSceneHandler (*this, name);
@@ -57,20 +57,20 @@
 }
 
-G4VViewer* G4OpenGLStoredWin32::CreateViewer
+G4VViewer* G4OpenGLStoredQt::CreateViewer
 (G4VSceneHandler& scene, const G4String& name) {
   G4VViewer* pView =
-    new G4OpenGLStoredWin32Viewer ((G4OpenGLStoredSceneHandler&) scene, name);
+    new G4OpenGLStoredQtViewer ((G4OpenGLStoredSceneHandler&) scene, name);
   if (pView) {
     if (pView -> GetViewId () < 0) {
       delete pView;
       pView = 0;
-      G4cerr << "G4OpenGLStoredWin32::CreateViewer: error flagged by"
-	" negative view id in G4OpenGLStoredWin32Viewer creation."
+      G4cerr << "G4OpenGLStoredQt::CreateViewer: error flagged by"
+	" negative view id in G4OpenGLStoredQtViewer creation."
 	"\n Destroying view and returning null pointer." << G4endl;
     }
   }
   else {
-    G4cerr << "G4OpenGLStoredWin32::CreateViewer: null pointer on"
-      " new G4OpenGLStoredWin32Viewer." << G4endl;
+    G4cerr << "G4OpenGLStoredQt::CreateViewer: null pointer on"
+      " new G4OpenGLStoredQtViewer." << G4endl;
   }
   return pView;
@@ -25,12 +25,12 @@
 //
 // 
-// OpenGLStoredWin32 graphics system factory.
+// OpenGLStoredQt graphics system factory.
 
 
Index: /trunk/geant4/visualization/OpenGL/src/G4OpenGLStoredQtViewer.cc
===================================================================
--- /trunk/geant4/visualization/OpenGL/src/G4OpenGLStoredQtViewer.cc	(revision 532)
+++ /trunk/geant4/visualization/OpenGL/src/G4OpenGLStoredQtViewer.cc	(revision 533)
@@ -25,22 +25,22 @@
 //
 //
-// $Id: G4OpenGLStoredWin32Viewer.cc,v 1.18 2006/09/04 12:07:59 allison Exp $
+// $Id: G4OpenGLStoredQtViewer.cc,v 1.18 2007/06/25 12:07:59 $
 // GEANT4 tag $Name: geant4-08-02-patch-01 $
 //
 // 
 // Class G4OpenGLStoredWin32Viewer : a class derived from G4OpenGLWin32Viewer and
 //                             G4OpenGLStoredViewer.
 
-#ifdef G4VIS_BUILD_OPENGLWIN32_DRIVER
+#ifdef G4VIS_BUILD_OPENGLQT_DRIVER
 
-#include "G4OpenGLStoredWin32Viewer.hh"
+#include "G4OpenGLStoredQtViewer.hh"
 
 #include "G4ios.hh"
 
-G4OpenGLStoredWin32Viewer::G4OpenGLStoredWin32Viewer
+G4OpenGLStoredQtViewer::G4OpenGLStoredQtViewer
 (G4OpenGLStoredSceneHandler& sceneHandler,
  const G4String&  name):
 G4OpenGLViewer (sceneHandler),
-G4OpenGLWin32Viewer (sceneHandler),
+G4OpenGLQtViewer (sceneHandler),
 G4OpenGLStoredViewer (sceneHandler),
 G4VViewer (sceneHandler, sceneHandler.IncrementViewCount (), name) {
@@ -49,9 +49,9 @@
 }
 
-void G4OpenGLStoredWin32Viewer::Initialise () {
+void G4OpenGLStoredQtViewer::Initialise () {
 
   //Check that G4OpenGLWin32Viewer got a double buffered colour visual
 
-  CreateGLWin32Context ();
+  CreateGLQtContext ();
   CreateMainWindow ();
   CreateFontLists ();
@@ -65,8 +65,8 @@
 }
 
-void G4OpenGLStoredWin32Viewer::DrawView () {
+void G4OpenGLStoredQtViewer::DrawView () {
 
   //Make sure current viewer is attached and clean...
-  //Win32 version needed
+  //Qt version needed
   //  glXMakeCurrent (dpy, win, cx);
   glViewport (0, 0, WinSize_x, WinSize_y);
@@ -115,5 +115,5 @@
 
 //////////////////////////////////////////////////////////////////////////////
-void G4OpenGLStoredWin32Viewer::FinishView (
+void G4OpenGLStoredQtViewer::FinishView (
 ) 
 //////////////////////////////////////////////////////////////////////////////
@@ -25,22 +25,22 @@
 //
 // 
-// Class G4OpenGLStoredWin32Viewer : a class derived from G4OpenGLWin32Viewer and
+// Class G4OpenGLStoredQtViewer : a class derived from G4OpenGLQtViewer and
 //                             G4OpenGLStoredViewer.
 
@@ -49,9 +49,9 @@
 
-  //Check that G4OpenGLWin32Viewer got a double buffered colour visual
+  //Check that G4OpenGLQtViewer got a double buffered colour visual
 